@@ -836,19 +836,17 @@ class Feed:
     def __get_item_link(self, item):
         if item.guid:
             if not item.guid.has_key("ispermalink") or item.guid["ispermalink"].lower() == "true":
-                return item.guid.string
+                return self.__unquote_special(item.guid.string)
         if item.link:
             if item.link.has_key("href"):
-                return item.link["href"] #Atom uses href to store links
+                return self.__unquote_special(item.link["href"]) #Atom uses href to store links
             elif item.link.string:
-                return item.link.string
+                return self.__unquote_special(item.link.string)
             else:
                 # Once there was a feed with url in CData section
                 for node in item.link:
                     if node.string:
-                        str = node.string.strip()
-                        if str:
-                            return str
+                        return self.__unquote_special(node.string.strip())
 
 
     def __get_item_date(self, item):
